/***********************************************************************************************************************************
Execute Perl for Legacy Functionality
***********************************************************************************************************************************/
#ifndef PERL_EXEC_H
#define PERL_EXEC_H

/***********************************************************************************************************************************
Error message for errors thrown from embedded Perl
***********************************************************************************************************************************/
#define PERL_EMBED_ERROR                                            "===PERL-EMBED-ERROR==="

/***********************************************************************************************************************************
Functions
***********************************************************************************************************************************/
int perlExec(void);
void perlFree(int result);

#endif
